# 🏅 Bookshelf XP

This datapack provides tools to efficiently manage players' experience points and levels.

For more details and usage examples, check out the Bookshelf [documentation](https://docs.mcbookshelf.dev/en/latest/modules/xp.html).


## 📖 About Bookshelf

This module is part of the [Bookshelf Library](https://docs.mcbookshelf.dev/en/latest/index.html), a modular library datapack designed to simplify complex systems in Minecraft. Explore the full range of modules and discover how Bookshelf can simplify your Minecraft creations!
